/**********************************************************************/
/*                                                                    */
/* Copyright (c) 2001 by Sun Microsystems, Inc.                       */
/* All rights reserved.                                               */
/*                                                                    */
/**********************************************************************/

/*
** cics3270.h
**
** Sun MTP Client for Windows.
** EPI definitions.
*/

#ifndef INCL_CICS3270
#define INCL_CICS3270

#include <cicstype.h>
#include <dfhaid.h>
#include <dfhbmsca.h>

/**********************************************************************/
/*                                                                    */
/* This table is used to retrieve valid the binary equivelent of 3270 */
/* displayable characters. If a buffer address of 0x45 and 0x4f is    */
/* received in a datastream the two bytes translated would give 0x05  */
/* and 0x16 (101 binary) and (10110 binary). These are both treated   */
/* as 6 bit numbers which are concatenated to give a 12 bit address   */
/* 342 (000101010110 binary).                                         */
/*                                                                    */
/* Table entry values of 0xff represent untranslatable values.        */
/*                                                                    */
/**********************************************************************/
extern cics_ubyte_t cics_epi_ASCII_to_bin[128];

/**********************************************************************/
/*                                                                    */
/* This table is used to retrieve valid 3270 displayable characters   */
/* which can be transmitted to MTP. The main purpose of the table     */
/* is to allow calculation of a valid 12 bit encoded address from a   */
/* buffer address.                                                    */
/*                                                                    */
/* If a buffer address is 342 (101010110 binary) his would be split   */
/* two 6 bit numbers 101 binary and 10110 binary: 0x05 and 0x16. When */
/* the substitute values are extracted from the table the two         */
/* characters of the buffer address are 0x45 and 0x4f.                */
/*                                                                    */
/**********************************************************************/
extern cics_ubyte_t cics_epi_bin_to_ASCII[64];


/*
**  3270 command codes
*/
#define CICS_EPI_CMD_WRITE           0x31
#define CICS_EPI_CMD_READ_BUFFER     0x32
#define CICS_EPI_CMD_ERASE_WRITE     0x35
#define CICS_EPI_CMD_ERASE_WRITE_ALT 0x3D
#define CICS_EPI_CMD_EAU             0x3F

/*
** Write Control character bits - note that bit 5 is the MSB.
*/
#define CICS_EPI_WCC_RESET_MDT_BIT      0
#define CICS_EPI_WCC_KEYBOARD_RESET_BIT 1
#define CICS_EPI_WCC_ALARM_BIT          2
#define CICS_EPI_WCC_START_PRINT_BIT    3
#define CICS_EPI_WCC_PRINTER_BITB       4
#define CICS_EPI_WCC_PRINTER_BITA       5

/*
**  3270 Orders and attributes.
*/
#define CICS_EPI_ORDER_CR         DFHBMDCR
#define CICS_EPI_ORDER_EM         DFHBMPEM
#define CICS_EPI_ORDER_EUA        0x12
#define CICS_EPI_ORDER_FF         DFHBMPFF
#define CICS_EPI_ORDER_IC         0x13
#define CICS_EPI_ORDER_MF         0x1E
#define CICS_EPI_ORDER_NL         DFHBMPNL
#define CICS_EPI_ORDER_PT         0x09
#define CICS_EPI_ORDER_RA         0x14
#define CICS_EPI_ORDER_SA         0x1F
#define CICS_EPI_ORDER_SBA        0x11
#define CICS_EPI_ORDER_SF         0x1D
#define CICS_EPI_ORDER_SFE        0x10
#define CICS_EPI_ORDER_SFE_UNIKIX 0x89

/*
** EPI definitions for 3270 field attributes - these are bit positions
** bit 0 is the low order bit.
*/
#define CICS_EPI_ATTR_ALPHANUMERIC_BIT 4
#define CICS_EPI_ATTR_DISPLAY_BIT0     3
#define CICS_EPI_ATTR_DISPLAY_BIT1     2
#define CICS_EPI_ATTR_MDT_BIT          0
#define CICS_EPI_ATTR_PROTECTED_BIT    5
#define CICS_EPI_ATTR_RESERVED_BIT     1

/*
** EPI definitions of field attributes - see dfhbmsca.h
*/
#define CICS_EPI_FLD_ATT_BMASB DFHBMASB
#define CICS_EPI_FLD_ATT_BMASF DFHBMASF
#define CICS_EPI_FLD_ATT_BMASK DFHBMASK
#define CICS_EPI_FLD_ATT_BMBRY DFHBMBRY
#define CICS_EPI_FLD_ATT_BMDAR DFHBMDAR
#define CICS_EPI_FLD_ATT_BMFSE DFHBMFSE
#define CICS_EPI_FLD_ATT_BMPRF DFHBMPRF
#define CICS_EPI_FLD_ATT_BMPRO DFHBMPRO
#define CICS_EPI_FLD_ATT_BMUNN DFHBMUNN
#define CICS_EPI_FLD_ATT_BMUNP DFHBMUNP
#define CICS_EPI_FLD_ATT_PROTI DFHPROTI
#define CICS_EPI_FLD_ATT_PROTN DFHPROTN
#define CICS_EPI_FLD_ATT_UNIMD DFHUNIMD
#define CICS_EPI_FLD_ATT_UNINT DFHUNINT
#define CICS_EPI_FLD_ATT_UNNOD DFHUNNOD
#define CICS_EPI_FLD_ATT_UNNON DFHUNNON
#define CICS_EPI_FLD_ATT_UNNUM DFHUNNUM

/*
** EPI definitions of extended field attributes - see dfhbmsca.h
*/
#define CICS_EPI_ATT_TYPE_3270       DFH3270
#define CICS_EPI_ATT_TYPE_ALL        DFHALL
#define CICS_EPI_ATT_TYPE_CHARSET    DFHPS
#define CICS_EPI_ATT_TYPE_COLOR      DFHCOLOR
#define CICS_EPI_ATT_TYPE_HILITE     DFHHLT
#define CICS_EPI_ATT_TYPE_OUTLINE    DFHOUTLN
#define CICS_EPI_ATT_TYPE_SOSI       0xfe
#define CICS_EPI_ATT_TYPE_VALIDATION DFHVAL

/*
** EPI definitions of 3270 hilight attributes - see dfhbmsca.h.
*/
#define CICS_EPI_HILITE_BLINK      DFHBLINK
#define CICS_EPI_HILITE_DEFAULT    DFHDFHI
#define CICS_EPI_HILITE_NORMAL     '0'
#define CICS_EPI_HILITE_REVERSE    DFHREVRS
#define CICS_EPI_HILITE_UNDERSCORE DFHUNDLN

/*
** EPI definitions of 3270 colours - see dfhbmsca.h.
*/
#define CICS_EPI_COLOR_BLUE    DFHBLUE
#define CICS_EPI_COLOR_DEFAULT DFHDFCOL
#define CICS_EPI_COLOR_GREEN   DFHGREEN
#define CICS_EPI_COLOR_NEUTRAL DFHNEUTR
#define CICS_EPI_COLOR_PINK    DFHPINK
#define CICS_EPI_COLOR_RED     DFHRED
#define CICS_EPI_COLOR_TURQ    DFHTURQ
#define CICS_EPI_COLOR_YELLOW  DFHYELLO

/*
** EPI definitions for 3270 field validation attributes - these are bit
** positions bit 0 is the low order bit.
*/
#define CICS_EPI_FLD_VAL_MAND_ENTRY_BIT 1
#define CICS_EPI_FLD_VAL_MAND_FILL_BIT  2
#define CICS_EPI_FLD_VAL_TRIGGER_BIT    0

/*
** EPI definitions for the default character set and the DBCS char set.
*/
#define CICS_EPI_CHAR_SET_DBCS     '8'
#define CICS_EPI_CHAR_SET_DEFAULT  0x00

/*
** EPI definitions for field outlining attributes.
*/
#define CICS_EPI_OUTLINE_LEFT  0x08
#define CICS_EPI_OUTLINE_NONE  0x00
#define CICS_EPI_OUTLINE_OVER  0x04
#define CICS_EPI_OUTLINE_RIGHT 0x02
#define CICS_EPI_OUTLINE_UNDER 0x01

/*
** EPI definitions SOSI.
*/
#define CICS_EPI_SOSI_DISABLED 0x00
#define CICS_EPI_SOSI_ENABLED  0x01

/*
**  AID definitions.
*/
#define CICS_EPI_AID_CLEAR           DFHCLEAR
#define CICS_EPI_AID_CLEAR_PARTITION DFHCLRP
#define CICS_EPI_AID_ENTER           DFHENTER
#define CICS_EPI_AID_MAG_RDR_NUM     DFHMSRE
#define CICS_EPI_AID_OP_ID           DFHOPID
#define CICS_EPI_AID_PA1             DFHPA1
#define CICS_EPI_AID_PA2             DFHPA2
#define CICS_EPI_AID_PA3             DFHPA3
#define CICS_EPI_AID_PF1             DFHPF1
#define CICS_EPI_AID_PF10            DFHPF10
#define CICS_EPI_AID_PF11            DFHPF11
#define CICS_EPI_AID_PF12            DFHPF12
#define CICS_EPI_AID_PF13            DFHPF13
#define CICS_EPI_AID_PF14            DFHPF14
#define CICS_EPI_AID_PF15            DFHPF15
#define CICS_EPI_AID_PF16            DFHPF16
#define CICS_EPI_AID_PF17            DFHPF17
#define CICS_EPI_AID_PF18            DFHPF18
#define CICS_EPI_AID_PF19            DFHPF19
#define CICS_EPI_AID_PF2             DFHPF2
#define CICS_EPI_AID_PF20            DFHPF20
#define CICS_EPI_AID_PF21            DFHPF21
#define CICS_EPI_AID_PF22            DFHPF22
#define CICS_EPI_AID_PF23            DFHPF23
#define CICS_EPI_AID_PF24            DFHPF24
#define CICS_EPI_AID_PF3             DFHPF3
#define CICS_EPI_AID_PF4             DFHPF4
#define CICS_EPI_AID_PF5             DFHPF5
#define CICS_EPI_AID_PF6             DFHPF6
#define CICS_EPI_AID_PF7             DFHPF7
#define CICS_EPI_AID_PF8             DFHPF8
#define CICS_EPI_AID_PF9             DFHPF9
#define CICS_EPI_AID_SEL_PEN_ATT     DFHPEN
#define CICS_EPI_AID_TRIGGER         DFHTRIG

#endif
