/**********************************************************************/
/*                                                                    */
/* Copyright (c) 2001 by Sun Microsystems, Inc.                       */
/* All rights reserved.                                               */
/*                                                                    */
/**********************************************************************/

#ifndef _CICS_ECI_H
#define _CICS_ECI_H

/*
** This is the Sun MTP Client ECI interface definition file
*/

#include <cicstype.h>

#ifdef __cplusplus
  extern "C" {
#endif

#ifdef _WIN32
#pragma pack(1)
#endif

typedef void (CICSEXIT CICS_EciCallback_t)(cics_sshort_t);
typedef CICS_EciCallback_t CICSPTR *CICS_EciNotify_t;

/*
** Values for eci_call_type in ECI_PARMS structure
*/
#define ECI_SYNC                     516    
#define ECI_ASYNC                    517
#define ECI_ASYNC_NOTIFY_MSG         518
#define ECI_ASYNC_NOTIFY_SEM         519
#define ECI_GET_REPLY                520
#define ECI_GET_REPLY_WAIT           521
#define ECI_STATE_SYNC               522 
#define ECI_STATE_ASYNC              523 
#define ECI_STATE_ASYNC_SEM          524 
#define ECI_STATE_ASYNC_MSG          525 
#define ECI_GET_SPECIFIC_REPLY       528
#define ECI_GET_SPECIFIC_REPLY_WAIT  529

/*
** Values for eci_extend mode in ECI_PARMS structure
*/
#define ECI_NO_EXTEND                0   
#define ECI_EXTENDED                 1   
#define ECI_COMMIT                   2   
#define ECI_CANCEL                   2
/* Same as ECI_COMMIT               */
#define ECI_BACKOUT                  3   
#define ECI_STATE_IMMEDIATE          4   
#define ECI_STATE_CHANGED            5   
#define ECI_STATE_CANCEL             6   


/*
** The following define should be used to set the 'eci_version' 
** field of the ECI parameter block.
*/  

/*
** MTP Specific Values
*/
#define ECI_UNIKIX_VERSION_1        -1  
#define ECI_UNIKIX_VERSION_1A       -2  

/*
** IBM compatible Values for eci_version in ECI_PARMS structure
*/
#define ECI_VERSION_1                1  
#define ECI_VERSION_1A               2  
#define ECI_VERSION_MAX              2   


/*
** Value for eci_luw_token in ECI_PARMS structure
*/
#define ECI_LUW_NEW                  0L


typedef struct
{
    cics_sshort_t    eci_call_type;     
    cics_char_t      eci_program_name[8];
    cics_char_t      eci_userid[8];      
    cics_char_t      eci_password[8];    
    cics_char_t      eci_transid[4];    
    cics_char_t      eci_abend_code[4]; 
    cics_ptr_t       eci_commarea;      
    cics_sshort_t    eci_commarea_length;
    cics_sshort_t    eci_timeout;        
    cics_sshort_t    eci_sys_return_code;
    cics_sshort_t    eci_extend_mode;    
    union
    {
	cics_lhandle_t	window_handle;
	cics_lhandle_t	sem_handle;
	struct
	{
	    cics_shandle_t	hwnd;
	    cics_shandle_t	hinstance;
	} win_fields;
    } eci_async_notify;
    cics_ushort_t    eci_message_id;     
    cics_sshort_t    eci_message_qualifier;
    cics_slong_t     eci_luw_token;     
    cics_char_t      eci_sysid[4];      
    cics_sshort_t    eci_version;       
    cics_char_t      eci_system_name[8]; 
    CICS_EciNotify_t eci_callback;      
    cics_char_t      eci_userid2[16];		/* This field is ignored */
    cics_char_t      eci_password2[16];  	/* This field is ignored */
    cics_char_t      eci_tpn[4];		/* Only in VERSION_1A */
} ECI_PARMS;

#define eci_window_handle	eci_async_notify.window_handle
#define eci_sem_handle		eci_async_notify.sem_handle

typedef ECI_PARMS CICSPTR *PECI_PARMS;

#define CICS_ECI_SYSTEM_MAX          8
#define CICS_ECI_DESCRIPTION_MAX     60
typedef struct
{
    cics_char_t SystemName[CICS_ECI_SYSTEM_MAX+1];
    cics_char_t Description[CICS_ECI_DESCRIPTION_MAX+1];
} CICS_EciSystem_t;


cics_sshort_t CICSCALL CICS_ExternalCall(ECI_PARMS CICSPTR *EciParms);
cics_sshort_t CICSCALL CICS_EciListSystems(cics_char_t      CICSPTR *NameSpace,
                                           cics_ushort_t    CICSPTR *Systems,
                                           CICS_EciSystem_t CICSPTR *List);

/*
** The KixCli_QueryFD() function is only available on Unix Platforms.
*/
#ifndef _WIN32
cics_sshort_t KixCli_QueryFD( int *pFD );
#endif

#define ECI_NO_ERROR                 0
#define ECI_ERR_INVALID_DATA_LENGTH  -1
#define ECI_ERR_INVALID_EXTEND_MODE  -2
#define ECI_ERR_NO_CICS              -3
#define ECI_ERR_CICS_DIED            -4
#define ECI_ERR_REQUEST_TIMEOUT      -5
#define ECI_ERR_NO_REPLY             -5
/* Same as ECI_ERR_REQUEST_TIMEOUT   */
#define ECI_ERR_RESPONSE_TIMEOUT     -6
#define ECI_ERR_TRANSACTION_ABEND    -7
#define ECI_ERR_EXEC_NOT_RESIDENT    -8
#define ECI_ERR_LUW_TOKEN            -8
/* Same as ECI_ERR_EXEC_NOT_RESIDENT */
#define ECI_ERR_SYSTEM_ERROR         -9
#define ECI_ERR_NULL_WIN_HANDLE      -10
#define ECI_ERR_NULL_MESSAGE_ID      -12
#define ECI_ERR_THREAD_CREATE_ERROR  -13
#define ECI_ERR_INVALID_CALL_TYPE    -14
#define ECI_ERR_ALREADY_ACTIVE       -15
#define ECI_ERR_RESOURCE_SHORTAGE    -16
#define ECI_ERR_NO_SESSIONS          -17
#define ECI_ERR_NULL_SEM_HANDLE      -18
#define ECI_ERR_INVALID_DATA_AREA    -19
#define ECI_ERR_INVALID_VERSION      -21
#define ECI_ERR_UNKNOWN_SERVER       -22
#define ECI_ERR_CALL_FROM_CALLBACK   -23
#define ECI_ERR_INVALID_TRANSID      -24
#define ECI_ERR_MORE_SYSTEMS         -25
#define ECI_ERR_NO_SYSTEMS           -26
#define ECI_ERR_SECURITY_ERROR       -27
#define ECI_ERR_MAX_SYSTEMS          -28
#define ECI_ERR_MAX_SESSIONS         -29
#define ECI_ERR_ROLLEDBACK           -30

/*
** Values for ConnectionType in ECI_STATUS structure
*/
#define ECI_CONNECTED_NOWHERE        0
#define ECI_CONNECTED_TO_SERVER      1
#define ECI_CONNECTED_TO_CLIENT      2

/*
** Values for CicsServerStatus in ECI_STATUS structure
*/
#define ECI_SERVERSTATE_UNKNOWN      0
#define ECI_SERVERSTATE_UP           1
#define ECI_SERVERSTATE_DOWN         2

/*
** Values for CicsClientStatus in ECI_STATUS structure
*/
#define ECI_CLIENTSTATE_UNKNOWN      0
#define ECI_CLIENTSTATE_UP           1
#define ECI_CLIENTSTATE_INAPPLICABLE 2


typedef struct
{
    cics_sshort_t    ConnectionType;         
    cics_sshort_t    CicsServerStatus;       
    cics_sshort_t    CicsClientStatus;       
    cics_sshort_t    Reserved1;                 
    cics_sshort_t    Reserved2;                 
} ECI_STATUS;

#define ECI_STATUS_LENGTH sizeof(ECI_STATUS)   

#ifdef _WIN32
#pragma pack()
#endif

#ifdef __cplusplus
  }
#endif

#endif 
