/**********************************************************************/
/*                                                                    */
/* Copyright (c) 2001 by Sun Microsystems, Inc.                       */
/* All rights reserved.                                               */
/*                                                                    */
/**********************************************************************/

#ifndef _CICS_EPI_H
#define _CICS_EPI_H

#include <cicstype.h>

#ifdef __cplusplus
  extern "C" {
#endif
 
#ifdef _WIN32
#pragma pack(1)
#endif
/*
****
** Constants
****
*/

/*
** Lengths of fields
*/
#define CICS_EPI_SYSTEM_MAX            8
#define CICS_EPI_DESCRIPTION_MAX      60
#define CICS_EPI_NETNAME_MAX           8
#define CICS_EPI_TRANSID_MAX           4
#define CICS_EPI_ABEND_MAX             4
#define CICS_EPI_DEVTYPE_MAX          16
#define CICS_EPI_ERROR_MAX            60

/*
** Constants relating to TermIndex
*/
#define CICS_EPI_TERM_INDEX_NONE  0xFFFF
#define CICS_EPI_MIN_TERMINDEX         0
#define CICS_EPI_MAX_TERMINDEX        14
#define CICS_EPI_MAX_TERMINALS        15

/*
** Current Version Number
**    Note: CICS_EPI_VERSION_101 should be used.
*/
#define CICS_EPI_VERSION_100  0x00010000
#define CICS_EPI_VERSION_101  0x00010001

/*
** Return values for EPI calls
*/
#define CICS_EPI_NORMAL                0
#define CICS_EPI_ERR_NOT_INIT          1
#define CICS_EPI_ERR_BAD_INDEX         2
#define CICS_EPI_ERR_FAILED            3
#define CICS_EPI_ERR_VERSION           4
#define CICS_EPI_ERR_IS_INIT           5
#define CICS_EPI_ERR_NO_SYSTEMS        6
#define CICS_EPI_ERR_MORE_SYSTEMS      7
#define CICS_EPI_ERR_MAX_TERMS         8
#define CICS_EPI_ERR_SYSTEM            9
#define CICS_EPI_ERR_TRAN_ACTIVE      10
#define CICS_EPI_ERR_NO_DATA          11
#define CICS_EPI_ERR_TTI_ACTIVE       12
#define CICS_EPI_ERR_ATI_ACTIVE       13
#define CICS_EPI_ERR_NO_CONVERSE      14
#define CICS_EPI_ERR_ATI_STATE        15
#define CICS_EPI_ERR_NO_EVENT         16
#define CICS_EPI_ERR_MORE_EVENTS      17
#define CICS_EPI_ERR_MORE_DATA        18
#define CICS_EPI_ERR_WAIT             19
#define CICS_EPI_ERR_SERVER_DOWN      20
#define CICS_EPI_ERR_SENSE_CODE       21
#define CICS_EPI_ERR_SECURITY         22
#define CICS_EPI_ERR_IN_CALLBACK      23
#define CICS_EPI_ERR_NULL_PARM        24
/****
******** MTP Client Epi Specific Codes
****/
#define CICS_EPI_ERR_INVALID_DATA_LENGTH	50

/*
** Values for the 'Cause' field of CICS_EpiSysError_t
**   Note: These are environment specific.
*/
#define CICS_EPI_SYSERROR_UNEXPECTED_DATASTREAM		100L
#define CICS_EPI_SYSERROR_NO_MEMORY			101L
#define CICS_EPI_SYSERROR_DUPLICATE_NETNAME		102L
#define CICS_EPI_SYSERROR_UNKNOWN_NETNAME		103L
#define CICS_EPI_SYSERROR_UNKNOWN_DEVTYPE		104L
#define CICS_EPI_SYSERROR_INVALID_TPNAME		105L
#define CICS_EPI_SYSERROR_UNEXPECTED_ERROR		106L
#define CICS_EPI_SYSERROR_UNKNOWN_SYSTEM		107L
#define CICS_EPI_SYSERROR_TERM_OUT_OF_SERVICE		108L
#define CICS_EPI_SYSERROR_SYSTEM_UNAVAILABLE		109L
#define CICS_EPI_SYSERROR_INTERNAL_LOGIC_ERROR		110L
#define CICS_EPI_SYSERROR_AUTOINSTALL_FAILED		111L
#define CICS_EPI_SYSERROR_TERM_INSTALL_FAILED		112L
#define CICS_EPI_SYSERROR_MAX_SYSTEMS			113L
#define CICS_EPI_SYSERROR_TRANSPORT_INIT_FAILED		114L

/*
*****
** Data Types and Values
*****
*/

typedef cics_ushort_t CICS_EpiEnd_t;
#define CICS_EPI_END_SIGNOFF     1 
#define CICS_EPI_END_SHUTDOWN    2 
#define CICS_EPI_END_OUTSERVICE  3 
#define CICS_EPI_END_UNKNOWN     4 
#define CICS_EPI_END_FAILED      5 

typedef cics_ushort_t CICS_EpiEvent_t;
#define CICS_EPI_EVENT_SEND      1
#define CICS_EPI_EVENT_CONVERSE  2
#define CICS_EPI_EVENT_END_TRAN  3
#define CICS_EPI_EVENT_START_ATI 4
#define CICS_EPI_EVENT_END_TERM  5

typedef cics_ushort_t CICS_EpiATIState_t;
#define CICS_EPI_ATI_ON          1
#define CICS_EPI_ATI_HOLD        2
#define CICS_EPI_ATI_QUERY       3

typedef cics_ushort_t CICS_EpiWait_t;
#define CICS_EPI_WAIT            1
#define CICS_EPI_NOWAIT          2
 
typedef cics_ushort_t CICS_EpiSenseCode_t; 
#define CICS_EPI_SENSE_OPCHECK   1 
#define CICS_EPI_SENSE_REJECT    2 

typedef struct
{
    cics_char_t           SystemName[CICS_EPI_SYSTEM_MAX+1];
    cics_char_t           Description[CICS_EPI_DESCRIPTION_MAX+1];
} CICS_EpiSystem_t;

typedef struct
{
    cics_char_t           NetName[CICS_EPI_NETNAME_MAX+1];
    cics_sshort_t         NumLines;
    cics_sshort_t         NumColumns;
    cics_ushort_t         MaxData;
    cics_sshort_t         ErrLastLine;
    cics_sshort_t         ErrIntensify;
    cics_sshort_t         ErrColor;
    cics_sshort_t         ErrHilight;
    cics_sshort_t         Hilight;
    cics_sshort_t         Color;
    cics_sshort_t         Printer;
} CICS_EpiDetails_t;

typedef struct
{
    cics_ushort_t         TermIndex;
    CICS_EpiEvent_t       Event;
    CICS_EpiEnd_t         EndReason;
    cics_char_t           TransId[CICS_EPI_TRANSID_MAX+1];
    cics_char_t           AbendCode[CICS_EPI_ABEND_MAX+1];
    cics_ubyte_t CICSPTR *Data;
    cics_ushort_t         Size;
} CICS_EpiEventData_t;

typedef struct
{
    cics_ulong_t          Cause;
    cics_ulong_t          Value;
    cics_char_t           Msg[CICS_EPI_ERROR_MAX+1];
} CICS_EpiSysError_t;

/*
** EPI callback notification function definition.
*/
typedef void (CICSEXIT CICS_EpiCallback_t)(cics_ushort_t TermIndex);
typedef CICS_EpiCallback_t CICSPTR *CICS_EpiNotify_t;

/*
*****
** Function prototypes for EPI.
*****
*/

cics_sshort_t CICSCALL CICS_EpiInitialize(cics_ulong_t  Version);
                                            
cics_sshort_t CICSCALL CICS_EpiTerminate(void);

cics_sshort_t CICSCALL CICS_EpiListSystems(cics_char_t      CICSPTR *NameSpace,
                                           cics_ushort_t    CICSPTR *Systems,
                                           CICS_EpiSystem_t CICSPTR *List);

cics_sshort_t CICSCALL CICS_EpiAddTerminal(cics_char_t   CICSPTR *NameSpace,
                                           cics_char_t   CICSPTR *System,
                                           cics_char_t   CICSPTR *NetName,
                                           cics_char_t   CICSPTR *DevType,
                                           CICS_EpiNotify_t       NotifyFn,
                                           CICS_EpiDetails_t CICSPTR *Details,
                                           cics_ushort_t CICSPTR *TermIndex);

cics_sshort_t CICSCALL CICS_EpiInquireSystem(cics_ushort_t        TermIndex,
                                             cics_char_t CICSPTR *System);

cics_sshort_t CICSCALL CICS_EpiDelTerminal(cics_ushort_t TermIndex);

cics_sshort_t CICSCALL CICS_EpiStartTran(cics_ushort_t         TermIndex,
                                         cics_char_t  CICSPTR *TransId,
                                         cics_ubyte_t CICSPTR *Data,
                                         cics_ushort_t         Size);

cics_sshort_t CICSCALL CICS_EpiReply(cics_ushort_t         TermIndex,
                                     cics_ubyte_t CICSPTR *Data,
                                     cics_ushort_t         Size);

cics_sshort_t CICSCALL CICS_EpiATIState(cics_ushort_t               TermIndex,
                                        CICS_EpiATIState_t CICSPTR *ATIState);
 
cics_sshort_t CICSCALL CICS_EpiSenseCode(cics_ushort_t       TermIndex,
                                         CICS_EpiSenseCode_t SenseCode);

cics_sshort_t CICSCALL CICS_EpiGetEvent(cics_ushort_t                TermIndex,
                                        CICS_EpiWait_t               Wait,
                                        CICS_EpiEventData_t CICSPTR *Event);

cics_sshort_t CICSCALL CICS_EpiGetSysError(cics_ushort_t               TermIndex,
                                           CICS_EpiSysError_t CICSPTR *SysErr);

#ifdef _WIN32
#pragma pack()
#endif

#ifdef __cplusplus
  }
#endif
 
#endif /* _CICS_EPI_H */
